pub struct Image {
pub draw_bg: DrawImage,
/* private fields */
}Fields
draw_bg: DrawImageImplementations
Sourceimpl Image
impl Image
Sourcepub fn size_in_pixels(&self, cx: &mut Cx) -> Option<(usize, usize)>
pub fn size_in_pixels(&self, cx: &mut Cx) -> Option<(usize, usize)>
Returns the original size of the image in pixels (not its displayed size).
Returns None if the image has not been loaded into a texture yet.
Sourcepub fn has_texture(&self) -> bool
pub fn has_texture(&self) -> bool
True if a texture has been set on this Image.
pub fn draw_walk(&mut self, cx: &mut Cx2d<'_, '_>, walk: Walk) -> DrawStep
Sourcepub fn load_image_file_by_path_async(
&mut self,
cx: &mut Cx,
image_path: &Path,
) -> Result<(), ImageError>
pub fn load_image_file_by_path_async( &mut self, cx: &mut Cx, image_path: &Path, ) -> Result<(), ImageError>
Loads the image at the given image_path on disk into this ImageRef.
pub fn load_image_from_data_async( &mut self, cx: &mut Cx, image_path: &Path, data: Arc<Vec<u8>>, ) -> Result<(), ImageError>