Modules

Structs

  • A sequence of commands that defines a set of contours, each of which consists of a sequence of line segments. Each contour is either open or closed.
  • A sequence of commands that defines a set of contours, each of which consists of a sequence of curve segments. Each contour is either open or closed.

Enums

Traits