pub enum VideoDataSource {
Dependency {
path: LiveDependency,
},
Network {
url: String,
},
Filesystem {
path: String,
},
}Expand description
The source of the video data.
[Dependency]: The path to a LiveDependency (an asset loaded with dep("crate://..)).
[Network]: The URL of a video file, it can be any regular HTTP download or HLS, DASH, RTMP, RTSP.
[Filesystem]: The path to a video file on the local filesystem. This requires runtime-approved permissions for reading storage.
Variants