Module makepad_widgets::makepad_vector::path
Modules
Structs
- A sequence of commands that defines a set of contours, each of which consists of a sequence of line segments. Each contour is either open or closed.
- A sequence of commands that defines a set of contours, each of which consists of a sequence of curve segments. Each contour is either open or closed.
Enums
- A command in a line path
- A command in a path
Traits
- An extension trait for iterators over line path commands.
- An extension trait for iterators over path commands.