Structs

  • An iterator over the commands that make up a line path.
  • A sequence of commands that defines a set of contours, each of which consists of a sequence of line segments. Each contour is either open or closed.